#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_AMUL_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_AMUL_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/amul.hpp>

#endif
